document.write("<table width=\"100%\" cellpadding=\"0\" cellspacing=\"0\">");
document.write("<tr bgcolor=\"#cccccc\"><td height=\"1\"></td></tr>");
document.write("<tr bgcolor=\"#ffffff\"><td height=\"1\"></td></tr>");
document.write("</table>");
document.write("<!-- sptable-->");
document.write("<table cellpadding=\"0\" cellspacing=\"0\">");
document.write("<tr height=\"24\"> ");
document.write("<td><img src=\"img/ol.gif\" alt=\"数字项目列表\" class=\"himg\" onclick=\"doExecute('InsertOrderedList')\"/></td>");
document.write("<td><img src=\"img/dl.gif\" alt=\"普通项目列表\" class=\"himg\" onclick=\"doExecute('InsertUnorderedList')\"/></td>");
document.write("<td><img src=\"img/sp.gif\" class=\"himg\"/></td>");
document.write("<td><img src=\"img/swf.gif\" alt=\"插入Flash\" class=\"himg\" onclick=\"doInsertFlash()\"/></td>");
document.write("<td><img src=\"img/media.gif\" alt=\"插入多媒体文件\" class=\"himg\" onclick=\"doInsertMedia()\"/></td>");
document.write("<td><img src=\"img/img.gif\" alt=\"插入图片\" class=\"himg\" onclick=\"doInsertImage()\"/></td>");
document.write("<td><img src=\"img/table.gif\" alt=\"插入表格\" class=\"himg\" onclick=\"doInsertTable()\"/></td>");
document.write("<td><img src=\"img/addon.gif\" alt=\"插入附件\" class=\"himg\" onclick=\"doInsertAddon()\"/></td> ");
document.write("<td><img src=\"img/link.gif\" alt=\"超链接\" class=\"himg\" onclick=\"doExecute('CreateLink')\"/></td>");
document.write("<td><img src=\"img/sp.gif\" class=\"himg\"/></td>");
document.write("<td><img src=\"img/u.gif\" alt=\"下划线\" class=\"himg\" onclick=\"doExecute('Underline')\"/></td>");
document.write("<td><img src=\"img/b.gif\" alt=\"粗体\" class=\"himg\" onclick=\"doExecute('Bold')\"/></td>");
document.write("<td><img src=\"img/i.gif\" alt=\"斜体\" class=\"himg\" onclick=\"doExecute('Italic')\"/></td>");
document.write("<td><img src=\"img/sp.gif\" class=\"himg\"/></td>");
document.write("<td><img src=\"img/nbsp.gif\" alt=\"空格\" class=\"himg\" onclick=\"doInsertBn()\"/></td>");
document.write("<td><img src=\"img/br.gif\" alt=\"换行\" class=\"himg\" onclick=\"doInsertBr()\"/></td>");
document.write("<td><img src=\"img/hr.gif\" alt=\"水平线\" class=\"himg\" onclick=\"doExecute('InsertHorizontalRule')\"/></td>");
document.write("<td><img src=\"img/sp.gif\" class=\"himg\"/></td>");
document.write("<td><img src=\"img/copy.gif\" alt=\"复制\" class=\"himg\" onclick=\"doExecute('Copy')\"/></td>");
document.write("<td><img src=\"img/par.gif\" alt=\"粘贴\" class=\"himg\" onclick=\"doExecute('Paste')\"/></td>");
document.write("<td><img src=\"img/sp.gif\" class=\"himg\"/></td>");
document.write("<td><img src=\"img/quote.gif\" alt=\"引用\" class=\"himg\" onClick=\"doInsertQuote()\"/></td>");
document.write("<td><img src=\"img/group.gif\"alt=\"组分栏框\" class=\"himg\" onClick=\"doInsertGroup()\"/></td>");
document.write("<td><img src=\"img/sp.gif\" class=\"himg\"/></td>");
document.write("<td><img src=\"img/color.gif\" alt=\"字体颜色\" class=\"himg\" onclick=\"doFontColor()\"></td>");
document.write("</tr>");
document.write("</table>");
document.write("<table width=\"100%\" cellpadding=\"0\" cellspacing=\"0\">");
document.write("<tr bgcolor=\"#cccccc\"><td height=\"1\"></td></tr>");
document.write("<tr bgcolor=\"#ffffff\"><td height=\"1\"></td></tr>");
document.write("</table>");